package org.springframework.webfluxbasepathmutate;

import org.springframework.core.annotation.Order;
import org.springframework.stereotype.Component;
import org.springframework.web.server.ServerWebExchange;
import org.springframework.web.server.WebFilter;
import org.springframework.web.server.WebFilterChain;
import reactor.core.publisher.Mono;

@Component
@Order(1)
public class InjectHeaderWebFilter implements WebFilter {

    @Override
    public Mono<Void> filter(ServerWebExchange exchange, WebFilterChain chain) {
        final var mutatedRequest = exchange.getRequest().mutate()
                .header("X-Injected-Header", "Hello, world!")
                .build();

        // The RequestPath of the mutated object now contains the correct URI, but lost its contextPath attribute
        // and thus the "pathWithinApplication" used for routing. HelloController#hello() will not be called.

        final var mutatedExchange = exchange.mutate()
                .request(mutatedRequest)
                .build();

        return chain.filter(mutatedExchange);
    }
}
